@@ -145,6 +145,4 @@ class AES_FUNC():
         plain_text = self.cryptor.decrypt(a2b_hex(text)).decode()
         return plain_text.rstrip(' ')
 
-func = AES_FUNC("hhxx2020TTXS")
-ss = func.encrypt("bitchjolin")
-ss = 0
+
